View source: R/choice_identifiers.R
| read_Tp | R Documentation |
TpThis helper function reads the number of choice occasions Tp from a
choice_identifiers object.
read_Tp(choice_identifiers)
choice_identifiers |
[ |
An integer vector of length N, where N is the
number of deciders.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.